#------------------------------------------------------------------------------
# Copyright (c) 2005, Enthought, Inc.
# All rights reserved.
#
# This software is provided without warranty under the terms of the BSD
# license included in enthought/LICENSE.txt and may be redistributed only
# under the conditions described in the aforementioned license.  The license
# is also available online at http://www.enthought.com/licenses/BSD.txt
# Thanks for using Enthought open source!
#
# Author: Enthought, Inc.
# Description: <Enthought enable package component>
#------------------------------------------------------------------------------


# Import the toolkit specific version.
from .toolkit import toolkit_object
NativeScrollBar = toolkit_object('NativeScrollBar')

#### EOF ######################################################################
